# Credits

The `kiwi-platform-py` project is owned by the Software Platform Squad at Kiwi.com.
The interim maintainer, until the project reaches maturity, is [Bence Nagy (underyx)](https://underyx.me).

A full list of contributors can be found on [GitHub's Contributors page](https://github.com/kiwicom/kiwi-platform-py/graphs/contributors)
or you can obtain it on your own by running `git shortlog -sn`.
